.. Copyright 2013, 2014, 2016 Reahl Software Services (Pty) Ltd. All rights reserved.

Modules reahl.domainui.accounts and reahl.domainui.bootstrap.accounts
---------------------------------------------------------------------

.. note::

   These modules have identical APIs.

The older version (reahl.domainui.accounts)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: reahl.domainui.accounts


AccountUI
"""""""""

.. autoclass:: AccountUI
   :members:


The Bootstrap-styled version (reahl.domainui.bootstrap.accounts)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: reahl.domainui.bootstrap.accounts


AccountUI
"""""""""

.. autoclass:: AccountUI
   :members:
